# UTF-8 encoded Ukrainian translation file for use with Oddmuse
#
# Copyright (c) 2006  Victor Anyakin <anyakinvictor@yahoo.com>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: ukrainian-utf8.pl,v 1.5 2007/08/19 11:42:08 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Не дозволено читати: користувач, IP, або мережа заблоковані.
Login
Ввійти
Error

%s calls

Could not create %s
Не вдалось створити %s
Invalid UserName %s: not saved.
Неправильне ім'я користувача %s: не збережено
UserName must be 50 characters or less: not saved
Ім'я користувача має бути довжиною не більше 50 символів: не збережено
This page contains an uploaded file:
Ця сторінка містить завантажений файл:
Recursive include of %s!
Рекурсивне включення %s!
Clear Cache

Main lock obtained.
Отримано основний замок.
Main lock released.
Знято основний блок.
Journal

More...

Comments on this page
Коментарі до цієї сторінки
XML::RSS is not available on this system.
XML::RSS не доступний на цій системі.
diff
різниця
history
історія
%s returned no data, or LWP::UserAgent is not available.
%s повернув порожню відповідь, або LWP::UserAgent не доступний. 
RSS parsing failed for %s
Не вдалось проаналізувати RSS для %s
No items found in %s.
Жодних елементів не знайдено в %s
 . . . . 
 . . . .
Click to edit this page
Натисніть щоб відредагувати цю сторінку
CGI Internal error: %s
Внутрішня помилка CGI: %s
Invalid action parameter %s
Неприпустимий параметр дії: %s
Invalid URL.
Невірний URL.
Page name is missing
Ім'я сторінки відсутнє
Page name is too long: %s
Ім'я сторінки занадто довге: %s
Invalid Page %s (must not end with .db)
Невірна сторінка %s (має закінчуватись не .db)
Invalid Page %s (must not end with .lck)
Невірна сторінка %s (має закінчуватись не .lck)
Invalid Page %s
Невірна сторінка %s
Preview:
Попередній перегляд:
Preview only, not yet saved
Тільки попередній перегляд, ще не збережено
Please go on to %s.
Будь ласка, перейдіть на %s.
All changes for %s

No updates since %s
Жодних оновлень від %s
Updates since %s
Оновлення від %s
Updates in the last %s days
Оновлення за останні %s днів
Updates in the last %s day
Оновлення за останній %s день
for %s only
тільки для %s
List latest change per page only
Перелічити останні змінни лише по кожній сторінці
List all changes
Перелічити всі зміни
Skip rollbacks

Include rollbacks

List only major changes
Перелічити лише значні зміни
Include minor changes
Включити незначні зміни
%s days
%s днів
List later changes
Перелічити пізніші зміни
RSS

RSS with pages

RSS with pages and diff

Filters
Фільтри
Title:
Заголовок:
Title and Body:
Заголовок та тіло:
Username:
Ім'я користувача:
Host:
Хост:
Follow up to:

Language:
Мова:
Go!
Вперед!
(minor)
(незначне)
rollback
повернути
new
нове
from %s
від %s
: 

This page is too big to send over RSS.
Ця сторінка занадто велика для пересилання через RSS.
History of %s
Історія %s
Compare
Порівняти
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
Версія %s
Contributors to %s

Missing target for rollback.
Відсутня ціль для скасування змін.
Target for rollback is too far back.
Ціль для скасування змін занадто далека.
A username is required for ordinary users.

Rolling back changes
Скасовую зміни
The two revisions are the same.
Дві версії однакові.
Editing not allowed for %s.
Редагування не дозволено для %s.
Rollback to %s
Повернути до %s
%s rolled back
%s скасовані зміни
to %s

Index of all pages
Покажчик зі всіх сторінок
Wiki Version
Версія Вікі
Unlock Wiki
Розблокувати Вікі
Password
Пароль
Run maintenance
Запустити поточну профілактику
Unlock site
Розблокувати сайт
Lock site
Заблокувати сайт
Install CSS
Встановити CSS
Unlock %s
Розблокувати %s
Lock %s
Заблокувати %s
Administration
Адміністрування
Actions:
Дії:
Important pages:
Важливі сторінки:
To mark a page for deletion, put <strong>%s</strong> on the first line.
Для того, щоб помітити сторінку для видалення, вставте <strong>%s</strong> на першу строчку.
[Home]
[Перша сторінка]
redirected from %s
перенаправлено з %s
Click to search for references to this page
Натисніть для пошуку посилань на цю сторінку
Cookie: 
Кукі:
Warning
Попередження
Database is stored in temporary directory %s
База даних зберігається в тимчасовій директорії %s
%s seconds
%s секунд
The same page on other sites:
Ця сторінка на інших сайтах:
EditNearLinks

Last edited
Востаннє відредаговано
Edited
Відредаговано
by %s
%s
(diff)
(різниця)
Edit revision %s of this page
Редагувати версію %s цієї сторінки
Edit this page
Редагувати цю сторінку
e
e
This page is read-only
Ця сторінка тільки для читання
View other revisions
Дивитись інші версії
View current revision
Дивитись поточну версію
View all changes
Дивитись всі зміни
View contributors

Homepage URL:
Стартовий URL:
s
s
Save
Зберегти
p
p
Preview
Переглянути
Search:
Шукати:
f
f
Replace:
Замінити:
Delete

Validate HTML
Перевірити HTML
Validate CSS
Перевірити CSS
Last edit

Difference between revision %1 and %2
Різниця (між версією %1 до %2)
revision %s
версія %s
current revision
поточна версія
Last major edit (%s)

later minor edits

No diff available.
Різниці не доступні.
Old revision:
Стара версія:
Changed:
Змінено:
Deleted:

Added:
Додано:
to

Revision %s not available
Версія %s не доступна
showing current revision instead
натомість, показано поточну версію
Showing revision %s
Показано версію %s
Cannot save a nameless page.
Не можна зберегти безіменну сторінку.
Cannot save a page without revision.
Не можна зберегти сторінку без версії.
Cannot open %s
Неможливо відкрити %s
Cannot write %s
Неможливо записати %s
Cannot create %s
Неможливо створити %s
Could not get %s lock
Не вдалось отримати замок %s
The lock was created %s.
Створенно замок %s
This operation may take several seconds...
Операція може тривати декілька секунд...
Forced unlock of %s lock.
Примушено розблокування замка %s
No unlock required.
Розблокування не потрібне.
%s hours ago
%s годин тому
1 hour ago
1 годину тому
%s minutes ago
%s хвилин тому
1 minute ago
1 хвилину тому
%s seconds ago
%s секунд тому
1 second ago
1 секунду тому
just now
тільки що
Edit Denied
Редагування заборонено
Editing not allowed: user, ip, or network is blocked.
Редагування заборонено: користувач, IP, або мережа заблоковані.
Contact the wiki administrator for more information.
Зверніться до адміністратора Вікі за додатковою інформацією.
The rule %s matched for you.
Правило %s співпало.
See %s for more information.
Дивіться %s для додаткової інформації.
Editing not allowed: %s is read-only.
Редагування не дозволено: %s тільки для читання.
Only administrators can upload files.
Тільки адміністратори можуть завантажувати файли.
Editing revision %s of
Редагування версії %s
Editing %s
Редагування %s
Editing old revision %s.
Редагування старої версії %s.
Saving this page will replace the latest revision with this text.
Зберігання цієї сторінки замінить останню версію цим текстом.
Summary:
Підсумок:
This change is a minor edit.
Ця зміна є незначною.
Cancel

Replace this file with text
Замінити цей файл текстом
Replace this text with a file
Замінити цей текст файлом
File to upload: 
Файл для завантаження:
Files of type %s are not allowed.
Файли типу %s не дозволені.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваш пароль зберігається в кукі, в разі якщо вони у вас дозволені. Кукі можуть втрачатись, якщо ви під'эднаєтесь з іншої машини, іншого облікового запису, або, використовуючі інші програми.
You are currently an administrator on this site.
Наразі, ви адміністратор цього сайта.
You are currently an editor on this site.
Наразі, ви редактор на цьому сайті.
You are a normal user on this site.
Ви звичайний користувач сайту.
Your password does not match any of the  administrator or editor passwords.
Ваш пароль не збігається ні з паролєм адміністратора, ні з паролєм редактора.
Password:
Пароль:
This site does not use admin or editor passwords.
Цей сайт не використовує паролі адміністратора або редактора.
This operation is restricted to site editors only...
Операцію дозволено виконувати лише редакторам...
This operation is restricted to administrators only...
Операцію дозволено виконувати лише адміністраторам...
SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.
На цій сторінці "%2" відповідає правилу "%1"
Reason: %s.

Reason unknown.

Without normal pages
Без звичайних сторінок
Include normal pages
Включати звичайні сторінки
Without permanent anchors
Без постійних якорів
Include permanent anchors
Включити постійні якорі
Without near pages
Без близьких сторінок
Include near pages
Разом з близькими сторінками
(for %s)
(для %s)
Filter:
Фільтр:
%s pages found.
%s сторінок знайдено.
Replaced: %s
Замінено: %s
Search for: %s
Шукати: %s
View changes for these pages
Переглянути зміни на ції сторінках
Search sites on the %s as well
Шукати також сайти в %s
and
та
or
або
Fetching results from %s:
Отримую результати від %s:
Near pages:
Подібні сторінки:
last updated
востаннє оновлено
by

Transfer Error: %s
Помилка при передачі даних: %s
Browser reports no file info.
Глядач не повідомляє інформацію про файл.
Browser reports no file type.
Глядач не повідомляє про тип файлу.
The page contains banned text.
Сторінка містить заборонений текст.
No changes to be saved.
Відсутні зміни для збереження.
This page was changed by somebody else %s.
Цю сторінку було змінено ким то іншим %s.
The changes conflict.  Please check the page again.
Зміни конфліктують. Будь ласка, перевірте цю сторінку ще раз.
Please check whether you overwrote those changes.
Будь ласка, перевірте, чи перезаписали ви ці зміни.
Anonymous
Анонім
Cannot delete the index file %s.
Не можу видалити файл з покажчиком %s.
Please check the directory permissions.
Будь ласка, перевірте права доступа до директорії.
Your changes were not saved.
Зміни не збережено.
Could not get a lock to merge!
Не вдалось отримати замок для злияння!
you
ви
ancestor
попередник
other
інший
Run Maintenance
Запустити поточну профілактику
Maintenance not done.
Поточна профілактика не виконана.
(Maintenance can only be done once every 12 hours.)
(Поточна профілактика може запускатись кожні 12 годин.)
Remove the "maintain" file or wait.
Видаліть файл "maintain" або зачекайте.
Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted
видалено
Moving part of the %s log file.
Переміщення частини файлу журанала %s.
Could not open %s log file
Не вдалось відкрити файл протоколювання %s
Error was
Помилка була
Note: This error is normal if no changes have been made.
Примітка: Ця помилка припустима, якщо не було зроблено жодних змін.
Moving %s log entries.

Getting page index file for %s.

Set or Remove global edit lock
Встановити або Видалити глобальний блок редагування
Edit lock created.
Створенно блок на редагування.
Edit lock removed.
Видалено блок на редагування.
Set or Remove page edit lock
Встановити або Видалити блок на редагування сторінки
Lock for %s created.
Створено блок для %s.
Lock for %s removed.
Видалено блок для %s.
Displaying Wiki Version
Показую версію Вікі
Show dependencies
Показати залежності
Inter links:
Внутрішні посилання:
Near links:
Ближні посилання:
Show parsed link data
Показати проаналізовані дані посилання
Too many connections by %s
Забагато з'єднаннь від %s
Please do not fetch more than %1 pages in %2 seconds.
Будь ласка, не зчитуйте більше ніж %1 сторінок за %2 секунд.
Check whether the web server can create the directory %s and whether it can create files in it.
Перевірте, чи може веб сервер створити директорію %s і чи може він створювати в ній файли.
anchor first defined here: %s
якір вперше визначається тут: %s
Click to search for references to this permanent anchor
Клацніть щоб шукати посилання на цей постійний якір
the page %s also exists
сторінка %s також існує
Copy one of the following stylesheets to %s:
Копіювати одну із наступний таблиць стилей в %s:
Deleting %s
Видаляється %s
Deleted %s
Видалено %s
Renaming %1 to %2.
Переіменування %1 на %2
The page %s does not exist
Сторінка %s не існує
The page %s already exists
Сторінка %s вже існує
Cannot rename %1 to %2
Не можу переіменувати %1 на %2
Renamed to %s
Змінено ім'я на %s
Renamed from %s
Перейменовано з %s
Renamed %1 to %2.
Змінено ім'я %1 на %2.
Immediately delete %s
Одразу видалити %s
Rename %s to:
Змінити ім'я %s на:
Learn more...
Дізнатись більше...
Complete Content
Повний зміст
The main page is %s.
%s - основна сторінка.
Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

Cannot highlight the language %s.
Не можу підсвічувати мову %s.
Recent Visitors
Нещодавні відвідувачі
some action

was here

and read

Illegal year value: Use 0001-9999
Неприпустиме значення року: Використовуйте 0001-9999
The match parameter is missing.
Відсутній параметр для пошука.
Page Collection for %s
Колекція сторінок для %s
Previous
Попередня
Next
Наступна
Calendar %s
Календар %s
Su
Нд
Mo
Пн
Tu
Вт
We
Ср
Th
Чт
Fr
Пт
Sa
Сб
January
Січень
February
Лютий
March
Березень
April
Квітень
May
Травень
June
Червень
July
Липень
August
Серпень
September
Вересень
October
Жовтень
November
Листопад
December
Грудень
set %s

unset %s

Clustermap

Pages without a Cluster

Comments on 
Коментарі до
Comment on 
Коментувати
Compilation for %s
Компіляція для %s
Compilation tag is missing a regular expression.

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.
Не можу знайти версію %s.
Revert to revision %1: %2
Повернути до версії %1: %2
Marked as %s.
Помічено як %s
Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment
Додати коментар
ordinary changes
звичайні зміни
Matching page names:

Footnotes:
Примітки:
Could not find %1.html template in %2
Не вдалось знайти шаблон %1.html в %2
Only Editors are allowed to see this hidden page.
Тільки Редакторам дозволено бачити цю приховану сторінку.
Only Admins are allowed to see this hidden page.
Тільки Адміністраторам дозволено бачити цю приховану сторінку.
Index
Покажчик
Languages:
Мови:
Show!
Показати:
Define
Визначити
Full Link List
Повний перелік посилань
Template without parameters
Шаблон без параметрів
The template %s is either empty or does not exist.
Шаблон %s або порожній, або не існує.
 -- defined on %s
 -- визначено в %s
Local names defined on %1: %2
Локальні імена визначено в %1: %2
Register for %s
Зареєструвати для %s
Please choose a username of the form "FirstLast" using your real name.
Будь ласка, вкажіть ім'я користувача у вигляді "Ім'яПрізвище" використовуючі власні імена.
The passwords do not match.
Паролі не збігаються.
The password must be at least %s characters.
Пароль має містити щонайменше %s символів.
That email address is invalid.
Адреса поштової скриньки невірна.
The username %s has already been registered.
Користувач з ім'ям %s вже зареєстрований.
Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.
Повідомлення було відправлено "%s" з поадльшими інструціями.
There was an error saving your registration.
Виникла помилка при збереженні вашої реєстрації.
An account was created for %s.
Було створено обліковий запис для %s.
Login to %s
Увійти в систему %s
Username and/or password are incorrect.
Ім'я користувача та/або пароль не вірні.
Logged in as %s.
Зроблено вхід в систему як %s.
Logout of %s
Вийти з %s
Logout of %s?
Вийти з %s?
Logged out of %s
Зроблено вихід із %s
You are now logged out.
Тепер ви вийшли із системи.
Register a new account
Зареєструвати новий обліковий запис
Logout
Вийти
Who am I?
Хто я?
Forgot your password?
Забули пароль?
Change your password
Змініть свій пароль
Approve pending registrations

Confirm Registration for %s
Підтвердіть реєстрацію для %s
%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?
Хто я?
You are logged in as %s.
Ви увійшли як %s.
You are not logged in.
Ви не увішли в систему.
Reset Password
Скинути пароль.
The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.
Користувача з іменем "%s" не існує.
Reset Password for %s

Reset Password?

Change Password for %s
Змінити пароль для %s
Change Password?
Змінити пароль?
Your current password is incorrect.
Ваш поточний пароль не вірний.
Your password has been changed.
Ваш пароль було змінено.
Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>
<ul>
<li>%1 - %2</li>
<li>%1 - %2</li>
</ul>
</ul>
There are no pending registrations.

%s is not a legal name for a namespace

 (create locally)

image
зображення
download
завантажити
Clearing Cache
Очещення кешу
Done.
Зроблено.
Generating Link Database
Генерую базу даних посилань
The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view
дивитись
Self-ban by %s

You have banned your own IP.
Ви заборонили власний IP.
Orphan List

Trail: 
Слід:
None
Немає
Type
Тип
Permalink to "%s"
Постійне посилання на "%s"
There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
Виникла помилка при генеруванні pdf для %s. Будь ласка, повідомте про це вебмастера, але не намагайтесь завантажити ще раз, це не спрацює.
Someone else is generating a pdf for %s.  Please wait a minute and then try again.
Хтось інший генерує pdf для %s. Будь ласка, зачекайте хвилинку і спробуйте знову.
Download this page as PDF
Скачати цю сторінку в форматі PDF
Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.
Ви відповили невірно.
Use the back button to return the previous page and try again.

To save this page you must answer this question:

Referrers

All Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.
Модуль Search::FreeText не доступний на цій системі.
Rebuilding index not done.
Перебудова покажника не виконана.
(Rebuilding the index can only be done once every 12 hours.)

 ... 
 ...
Search term missing.
Відсутній ключ для пошуку.
Result pages: 
Результати пошуку:
(%s results)
(%s результатів)
Tags:

Tags: %s.

No tags

Slideshow:%s
Показ слайдів: %s
Index of all small pages

Static Copy
Статична копія
Back to %s
Назад до %s
Copy to %1 succeeded: %2.
Копіювання в %1 виконано: %2.
Copy to %1 failed: %2.
Не вдалось скопіювати в %1: %2
Alternatively, use one of the following templates:
Як варіант, використовуйте один із наступних шаблонів:
Thread: %s
Тред: %s
ID parameter is missing.
параметр ID відсутній.
Thread %s does not exist.
Тред %s не існує.
Page %s does not contain a thread.
Сторінка %s не містить тред.
Add
Додати
URL parameter is missing.
Параметр URL відсутній.
Add to %s thread
Додати до треду %s
Below:
Нижче:
URL:
URL:
Name:
Ім'я:
Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents
Зміст
Create a new page for today

This page is a translation of %s. 
Ця сторінка є перекладом %s.
The translation is up to date.
Переклад відповідає останній версії.
The translation is outdated.
Переклад застарів.
The page does not exist.
Сторінка не існує
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
альтернативний
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
пошук
Wanted Pages

%s pages

%s, referenced from:

Upload of %s file
Завантаження файла %s
Blog
Блог
Matching pages:

New
Нова
Edit %s.
Редагувати %s.
Title: 

Tags: 

END_OF_TRANSLATION
